@@ -2,16 +2,23 @@ from pathlib import Path
 from abc import abstractmethod
 from typing import Union
 
+from trcli.cli import Environment
+from trcli.data_classes.dataclass_testrail import TestRailSuite
+
 
 class FileParser:
     """
     Each new parser should inherit from this class, to make file reading modular.
     """
 
-    def __init__(self, filepath: Union[str, Path]):
+    def __init__(self, environment: Environment):
+        filepath = environment.file
         self.filepath = filepath
         self.check_file(filepath)
         self.filename = Path(filepath).name
+        self.case_matcher = environment.case_matcher
+        self.env = environment
+        self.special = environment.special_parser
 
     @staticmethod
     def check_file(filepath: Union[str, Path]):
@@ -19,5 +26,5 @@ class FileParser:
             raise FileNotFoundError("File not found.")
 
     @abstractmethod
-    def parse_file(self):
+    def parse_file(self) -> list[TestRailSuite]:
         raise NotImplementedError
